@@ -39,8 +39,8 @@ _pkg_config = {
     'sip_config_args':  '-b /usr/bin -d /usr/lib/python2.6/site-packages -e /usr/include/python2.6 CFLAGS=-O2 -march=armv4t CXXFLAGS=-O2 -march=armv4t',
     'sip_inc_dir':      '/usr/include/python2.6',
     'sip_mod_dir':      '/usr/lib/python2.6/site-packages',
-    'sip_version':      0x040a02,
-    'sip_version_str':  '4.10.2',
+    'sip_version':      0x040b02,
+    'sip_version_str':  '4.11.2',
     'universal':        ''
 }
 
@@ -103,6 +103,7 @@ _default_macros = {
     'LFLAGS_OPENGL':            '',
     'LFLAGS_PLUGIN':            '-shared',
     'LFLAGS_RELEASE':           '',
+    'LFLAGS_RPATH':             '',
     'LFLAGS_SHLIB':             '-shared',
     'LFLAGS_SONAME':            '-Wl,-soname,',
     'LFLAGS_THREAD':            '',
@@ -121,6 +122,7 @@ _default_macros = {
     'LIBS_RT':                  '',
     'LIBS_RTMT':                '',
     'LIBS_THREAD':              '-lpthread',
+    'LIBS_WEBKIT':              '',
     'LIBS_WINDOWS':             '',
     'LIBS_X11':                 '-lXext -lX11 -lm',
     'LINK':                     'g++',
@@ -555,7 +557,7 @@ class Makefile:
 
                 libs.append(self.platform_lib(py_lib))
 
-        if self.generator in ("MSVC", "MSVC.NET", "BMAKE"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD", "BMAKE"):
             if win_exceptions:
                 cflags_exceptions = "CFLAGS_EXCEPTIONS_ON"
                 cxxflags_exceptions = "CXXFLAGS_EXCEPTIONS_ON"
@@ -609,7 +611,7 @@ class Makefile:
             cxxflags_debug = "CXXFLAGS_RELEASE"
             lflags_debug = "LFLAGS_RELEASE"
 
-        if self.generator in ("MSVC", "MSVC.NET", "BMAKE"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD", "BMAKE"):
             if self._threaded:
                 cflags.extend(self.optional_list(cflags_mt))
                 cxxflags.extend(self.optional_list(cxxflags_mt))
@@ -649,6 +651,8 @@ class Makefile:
                     # Note that qmake doesn't define anything for QtHelp.
                     if mod == "QtCore":
                         defines.append("QT_CORE_LIB")
+                    elif mod == "QtDeclarative":
+                        defines.append("QT_DECLARATIVE_LIB")
                     elif mod == "QtGui":
                         defines.append("QT_GUI_LIB")
                     elif mod == "QtMultimedia":
@@ -688,12 +692,14 @@ class Makefile:
                     "QtCore":       "LIBS_CORE",
                     "QtGui":        "LIBS_GUI",
                     "QtNetwork":    "LIBS_NETWORK",
-                    "QtOpenGL":     "LIBS_OPENGL"
+                    "QtOpenGL":     "LIBS_OPENGL",
+                    "QtWebKit":     "LIBS_WEBKIT"
                 }
 
                 # For Windows: the dependencies between Qt libraries.
                 qdepmap = {
                     "QtAssistant":      ("QtNetwork", "QtGui", "QtCore"),
+                    "QtDeclarative":    ("QtNetwork", "QtGui", "QtCore"),
                     "QtGui":            ("QtCore", ),
                     "QtHelp":           ("QtSql", "QtGui", "QtCore"),
                     "QtMultimedia":     ("QtGui", "QtCore"),
@@ -761,7 +767,7 @@ class Makefile:
                 # Windows needs the version number appended if Qt is a DLL.
                 qt_lib = self.config.qt_lib
 
-                if self.generator in ("MSVC", "MSVC.NET", "BMAKE") and win_shared:
+                if self.generator in ("MSVC", "MSVC.NET", "MSBUILD", "BMAKE") and win_shared:
                     qt_lib = qt_lib + version_to_string(self.config.qt_version).replace(".", "")
 
                     if self.config.qt_edition == "non-commercial":
@@ -808,7 +814,7 @@ class Makefile:
             libs.extend(self.optional_list("LIBS_OPENGL"))
 
         if self._qt or self._opengl:
-            if self.config.qt_version < 0x040000 or "QtGui" in self._qt:
+            if self.config.qt_version < 0x040000 or self._opengl or "QtGui" in self._qt:
                 incdir.extend(self.optional_list("INCDIR_X11"))
                 libdir.extend(self.optional_list("LIBDIR_X11"))
                 libs.extend(self.optional_list("LIBS_X11"))
@@ -872,10 +878,11 @@ class Makefile:
                 lib = lib + "_debug"
 
         if sys.platform == "win32" and "shared" in self.config.qt_winconfig.split():
-            if (mname in ("QtCore", "QtDesigner", "QtGui", "QtHelp",
-                          "QtMultimedia", "QtNetwork", "QtOpenGL", "QtScript",
-                          "QtScriptTools", "QtSql", "QtSvg", "QtTest",
-                          "QtWebKit", "QtXml", "QtXmlPatterns", "phonon") or
+            if (mname in ("QtCore", "QtDeclarative", "QtDesigner", "QtGui",
+                          "QtHelp", "QtMultimedia", "QtNetwork", "QtOpenGL",
+                          "QtScript", "QtScriptTools", "QtSql", "QtSvg",
+                          "QtTest", "QtWebKit", "QtXml", "QtXmlPatterns",
+                          "phonon") or
                 (self.config.qt_version >= 0x040200 and mname == "QtAssistant")):
                 lib = lib + "4"
 
@@ -921,7 +928,11 @@ class Makefile:
         flags = []
         prefix = self.optional_string("RPATH")
 
-        if prefix:
+        if prefix == "":
+            # This was renamed in Qt v4.7.
+            prefix = self.optional_string("LFLAGS_RPATH")
+
+        if prefix != "":
             for r in rpaths:
                 flags.append(_quote(prefix + r))
 
@@ -933,7 +944,7 @@ class Makefile:
         clib is the library name in cannonical form.
         framework is set of the library is implemented as a MacOS framework.
         """
-        if self.generator in ("MSVC", "MSVC.NET", "BMAKE"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD", "BMAKE"):
             plib = clib + ".lib"
         elif sys.platform == "darwin" and framework:
             plib = "-framework " + clib
@@ -951,7 +962,7 @@ class Makefile:
         """
         prl_libs = []
 
-        if self.generator in ("MSVC", "MSVC.NET", "BMAKE"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD", "BMAKE"):
             prl_name = os.path.join(self.config.qt_lib_dir, clib + ".prl")
         elif sys.platform == "darwin" and framework:
             prl_name = os.path.join(self.config.qt_lib_dir, clib + ".framework", clib + ".prl")
@@ -1039,7 +1050,7 @@ class Makefile:
                 bdict[i] = ""
 
         # Generate the list of objects.
-        if self.generator in ("MSVC", "MSVC.NET", "BMAKE"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD", "BMAKE"):
             ext = ".obj"
         else:
             ext = ".o"
@@ -1137,7 +1148,7 @@ class Makefile:
 
         libs = []
 
-        if self.generator in ("MSVC", "MSVC.NET"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD"):
             libdir_prefix = "/LIBPATH:"
         else:
             libdir_prefix = "-L"
@@ -1174,7 +1185,7 @@ class Makefile:
         else:
             mfile.write(".SUFFIXES: .c .cpp .cc .cxx .C\n\n")
 
-        if self.generator in ("MSVC", "MSVC.NET"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD"):
             mfile.write("""
 {.}.cpp{}.obj::
 \t$(CXX) -c $(CXXFLAGS) $(CPPFLAGS) -Fo @<<
@@ -1616,7 +1627,7 @@ class ModuleMakefile(Makefile):
         mfile.write("\n")
 
         if self.static:
-            if self.generator in ("MSVC", "MSVC.NET", "BMAKE"):
+            if self.generator in ("MSVC", "MSVC.NET", "MSBUILD", "BMAKE"):
                 mfile.write("LIB = %s\n" % self.required_string("LIB"))
             elif self.generator == "MINGW":
                 mfile.write("AR = %s\n" % self.required_string("LIB"))
@@ -1650,7 +1661,7 @@ class ModuleMakefile(Makefile):
 
         mfile.write("\n$(TARGET): $(OFILES)\n")
 
-        if self.generator in ("MSVC", "MSVC.NET"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD"):
             if self.static:
                 mfile.write("\t$(LIB) /OUT:$(TARGET) @<<\n")
                 mfile.write("\t  $(OFILES)\n")
@@ -1832,7 +1843,7 @@ class ProgramMakefile(Makefile):
         if self.generator != "BMAKE":
             build.append(source)
 
-        if self.generator in ("MSVC", "MSVC.NET"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD"):
             build.append("-Fe")
             build.append("/link")
             libdir_prefix = "/LIBPATH:"
@@ -1885,7 +1896,7 @@ class ProgramMakefile(Makefile):
     def finalise(self):
         """Finalise the macros for a program Makefile.
         """
-        if self.generator in ("MSVC", "MSVC.NET"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD"):
             self.LFLAGS.append("/INCREMENTAL:NO")
 
         if self._manifest:
@@ -1942,7 +1953,7 @@ class ProgramMakefile(Makefile):
 
         mfile.write("\n$(TARGET): $(OFILES)\n")
 
-        if self.generator in ("MSVC", "MSVC.NET"):
+        if self.generator in ("MSVC", "MSVC.NET", "MSBUILD"):
             mfile.write("\t$(LINK) $(LFLAGS) /OUT:$(TARGET) @<<\n")
             mfile.write("\t  $(OFILES) $(LIBS)\n")
             mfile.write("<<\n")
@@ -2405,8 +2416,10 @@ def parse_build_macros(filename, names, overrides=None, properties=None):
         if line and line[0] != "#":
             assstart = line.find("+")
             if assstart > 0 and line[assstart + 1] == '=':
+                adding = True
                 assend = assstart + 1
             else:
+                adding = False
                 assstart = line.find("=")
                 assend = assstart
 
@@ -2417,6 +2430,11 @@ def parse_build_macros(filename, names, overrides=None, properties=None):
                 # Remove the escapes for any quotes.
                 rhs = rhs.replace(r'\"', '"').replace(r"\'", "'")
 
+                if adding and rhs != "":
+                    orig_rhs = raw.get(lhs)
+                    if orig_rhs is not None:
+                        rhs = orig_rhs + " " + rhs
+
                 raw[lhs] = rhs
 
         line = f.readline()
